Crate python_macros

Crate python_macros 

Python macro support for Rusty Python

This crate provides macro support for Python, allowing Rust code to interact with Python code more seamlessly.

Attribute Macros

python_function
Macro to define a Python function